@@ -97,7 +97,7 @@ void BookmarkManager::BookmarkTreeView::setExpandedData(const QModelIndex &index
 // -- BookmarkManager
 
 QMutex BookmarkManager::mutex;
-BookmarkManager* BookmarkManager::bookmarkManager = 0;
+BookmarkManager* BookmarkManager::bookmarkManager = nullptr;
 
 // -- public
 
@@ -116,7 +116,7 @@ void BookmarkManager::destroy()
 {
     TRACE_OBJ
     delete bookmarkManager;
-    bookmarkManager = 0;
+    bookmarkManager = nullptr;
 }
 
 QWidget* BookmarkManager::bookmarkDockWidget() const
@@ -124,7 +124,7 @@ QWidget* BookmarkManager::bookmarkDockWidget() const
     TRACE_OBJ
     if (bookmarkWidget)
         return bookmarkWidget;
-    return 0;
+    return nullptr;
 }
 
 void BookmarkManager::setBookmarksMenu(QMenu* menu)
@@ -155,15 +155,9 @@ void BookmarkManager::addBookmark(const QString &title, const QString &url)
 // -- private
 
 BookmarkManager::BookmarkManager()
-    : typeAndSearch(false)
-    , bookmarkMenu(0)
-    , m_toolBar(0)
-    , bookmarkModel(new BookmarkModel)
-    , bookmarkFilterModel(0)
-    , typeAndSearchModel(0)
+    : bookmarkModel(new BookmarkModel)
     , bookmarkWidget(new BookmarkWidget)
     , bookmarkTreeView(new BookmarkTreeView)
-    , bookmarkManagerWidget(0)
 {
     TRACE_OBJ
     bookmarkWidget->installEventFilter(this);
@@ -251,24 +245,23 @@ bool BookmarkManager::eventFilter(QObject *object, QEvent *event)
     if (event->type() == QEvent::KeyPress) {
         QKeyEvent *ke = static_cast<QKeyEvent*>(event);
         switch (ke->key()) {
-            case Qt::Key_F2: {
+            case Qt::Key_F2:
                 renameBookmark(bookmarkTreeView->currentIndex());
-            }   break;
+                break;
 
-            case Qt::Key_Delete: {
+            case Qt::Key_Delete:
                 removeItem(bookmarkTreeView->currentIndex());
                 return true;
-            }   break;
 
-            case Qt::Key_Up: {    // needs event filter on widget
+            case Qt::Key_Up:    // needs event filter on widget
             case Qt::Key_Down:
                 if (isWidget)
                     bookmarkTreeView->subclassKeyPressEvent(ke);
-            }   break;
+                break;
 
-            case Qt::Key_Escape: {
+            case Qt::Key_Escape:
                 emit escapePressed();
-            }   break;
+                break;
 
             default: break;
         }
@@ -366,7 +359,7 @@ void BookmarkManager::removeBookmarkActivated()
 void BookmarkManager::manageBookmarks()
 {
     TRACE_OBJ
-    if (bookmarkManagerWidget == 0) {
+    if (bookmarkManagerWidget == nullptr) {
         bookmarkManagerWidget = new BookmarkManagerWidget(bookmarkModel);
         connect(bookmarkManagerWidget, &BookmarkManagerWidget::setSource,
                 this, &BookmarkManager::setSource);
@@ -497,10 +490,10 @@ void BookmarkManager::customContextMenuRequested(const QPoint &point)
     if (!typeAndSearch && !bookmarkModel->parent(index).isValid())
         return;
 
-    QAction *remove = 0;
-    QAction *rename = 0;
-    QAction *showItem = 0;
-    QAction *showItemInNewTab = 0;
+    QAction *remove = nullptr;
+    QAction *rename = nullptr;
+    QAction *showItem = nullptr;
+    QAction *showItemInNewTab = nullptr;
 
     QMenu menu;
     if (!typeAndSearch && bookmarkModel->data(index, UserRoleFolder).toBool()) {
@@ -533,8 +526,9 @@ void BookmarkManager::focusInEventOccurred()
 
 void BookmarkManager::managerWidgetAboutToClose()
 {
-    delete bookmarkManagerWidget;
-    bookmarkManagerWidget = 0;
+    if (bookmarkManagerWidget)
+        bookmarkManagerWidget->deleteLater();
+    bookmarkManagerWidget = nullptr;
 
     storeBookmarks();
 }
