@@ -63,25 +63,6 @@ QHash<QString, QString> Generator::outputSuffixes;
 QString Generator::project_;
 QStringList Generator::scriptDirs;
 QStringList Generator::scriptFiles;
-QString Generator::sinceTitles[] =
-{
-    "    New Namespaces",
-    "    New Classes",
-    "    New Member Functions",
-    "    New Functions in Namespaces",
-    "    New Global Functions",
-    "    New Macros",
-    "    New Enum Types",
-    "    New Typedefs",
-    "    New Properties",
-    "    New Variables",
-    "    New QML Types",
-    "    New QML Properties",
-    "    New QML Signals",
-    "    New QML Signal Handlers",
-    "    New QML Methods",
-    ""
-};
 QStringList Generator::styleDirs;
 QStringList Generator::styleFiles;
 bool Generator::noLinkErrors_ = false;
@@ -403,6 +384,13 @@ QString Generator::fileBase(const Node *node) const
             base.prepend(QLatin1Char('-'));
             p = pp;
         }
+        if (node->isNamespace() && !node->name().isEmpty()) {
+            const NamespaceNode* ns = static_cast<const NamespaceNode*>(node);
+            if (!ns->isDocumentedHere()) {
+                base.append(QLatin1String("-sub-"));
+                base.append(ns->tree()->camelCaseModuleName());
+            }
+        }
     }
 
     // the code below is effectively equivalent to:
@@ -661,21 +649,10 @@ QString Generator::fullDocumentLocation(const Node *node, bool useSubdir)
         break;
     }
 
-    // Various objects can be compat (deprecated) or obsolete.
-    // Is this even correct?
     if (!node->isClass() && !node->isNamespace()) {
-        switch (node->status()) {
-        case Node::Compat:
-            parentName.replace(QLatin1Char('.') + currentGenerator()->fileExtension(),
-                               "-compat." + currentGenerator()->fileExtension());
-            break;
-        case Node::Obsolete:
+        if (node->status() == Node::Obsolete)
             parentName.replace(QLatin1Char('.') + currentGenerator()->fileExtension(),
                                "-obsolete." + currentGenerator()->fileExtension());
-            break;
-        default:
-            ;
-        }
     }
 
     return fdl + parentName.toLower() + anchorRef;
@@ -973,7 +950,7 @@ void Generator::generateBody(const Node *node, CodeMarker *marker)
     }
 }
 
-void Generator::generateClassLikeNode(Node* /* node */, CodeMarker* /* marker */)
+void Generator::generateCppReferencePage(Node* /* node */, CodeMarker* /* marker */)
 {
 }
 
@@ -1157,13 +1134,12 @@ void Generator::generateDocumentation(Node* node)
     CodeMarker *marker = CodeMarker::markerForFileName(node->location().filePath());
 
     if (node->parent() != 0) {
-        if ((node->isNamespace() && node->status() != Node::Intermediate)
-            || node->isClass()) {
+        if (node->isClass() || (node->isNamespace() && node->docMustBeGenerated())) {
             beginSubPage(node, fileName(node));
-            generateClassLikeNode(static_cast<Aggregate*>(node), marker);
+            generateCppReferencePage(static_cast<Aggregate*>(node), marker);
             endSubPage();
         }
-        if (node->isQmlType() || node->isJsType()) {
+        else if (node->isQmlType() || node->isJsType()) {
             beginSubPage(node, fileName(node));
             QmlTypeNode* qcn = static_cast<QmlTypeNode*>(node);
             generateQmlTypePage(qcn, marker);
@@ -1187,7 +1163,7 @@ void Generator::generateDocumentation(Node* node)
         int i = 0;
         while (i < aggregate->childNodes().count()) {
             Node *c = aggregate->childNodes().at(i);
-            if (c->isAggregate() && c->access() != Node::Private) {
+            if (c->isAggregate() && !c->isPrivate()) {
                 generateDocumentation((Aggregate*)c);
             }
             else if (c->isCollectionNode()) {
@@ -1384,20 +1360,6 @@ void Generator::generateStatus(const Node *node, CodeMarker *marker)
              << "We strongly advise against "
              << "using it in new code." << Atom::ParaRight;
         break;
-    case Node::Compat:
-        // reimplemented in HtmlGenerator subclass
-        if (node->isAggregate()) {
-            text << Atom::ParaLeft
-                 << Atom(Atom::FormattingLeft, ATOM_FORMATTING_BOLD)
-                 << "This "
-                 << typeString(node)
-                 << " is part of the Qt compatibility layer."
-                 << Atom(Atom::FormattingRight, ATOM_FORMATTING_BOLD)
-                 << " It is provided to keep old source code working. "
-                 << "We strongly advise against using it in new code."
-                 << Atom::ParaRight;
-        }
-        break;
     case Node::Internal:
     default:
         break;
